@@ -2,20 +2,16 @@ package Dist::Zilla::Plugin::NoTabsTests;
 BEGIN {
   $Dist::Zilla::Plugin::NoTabsTests::AUTHORITY = 'cpan:FLORA';
 }
-{
-  $Dist::Zilla::Plugin::NoTabsTests::VERSION = '0.05';
-}
 # ABSTRACT: (DEPRECATED) Release tests making sure hard tabs aren't used
-
+$Dist::Zilla::Plugin::NoTabsTests::VERSION = '0.07';
 use Moose;
 extends 'Dist::Zilla::Plugin::Test::NoTabs';
 
 use namespace::autoclean;
 
-# don't start warning just yet - give people a little bit of time to update
-#before register_component => sub {
-#    warn "!!! [NoTabsTests] is deprecated and may be removed in a future release; replace it with [Test::NoTabs]\n";
-#};
+before register_component => sub {
+    warn "!!! [NoTabsTests] is deprecated and may be removed in a future release; replace it with [Test::NoTabs]\n";
+};
 
 __PACKAGE__->meta->make_immutable;
 
@@ -23,7 +19,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =for :stopwords Florian Ragwitz
 
@@ -33,7 +29,7 @@ Dist::Zilla::Plugin::NoTabsTests - (DEPRECATED) Release tests making sure hard t
 
 =head1 VERSION
 
-version 0.05
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -50,9 +46,9 @@ providing the file F<xt/release/no-tabs.t>, a standard L<Test::NoTabs> test.
 
 THIS MODULE IS DEPRECATED. Please use
 L<Dist::Zilla::Plugin::Test::NoTabs> instead. it may be removed at a
-later time (but not before June 2014).
+later time (but not before October 2014).
 
-In the meantime, it will continue working -- although (soon) with a warning.
+In the meantime, it will continue working -- although with a warning.
 Refer to the replacement for the actual documentation.
 
 =head1 AUTHOR
